@@ -12,45 +12,37 @@
 
 from __future__ import absolute_import
 
-from distutils.version import StrictVersion as _sv
+from packaging.version import Version, parse
 import sys
 import numpy
 
-version = "0.18.0"
+version = "0.24.0"
 
 hdf5_version = "REST"
 
-_exp = _sv(version)
+_exp = parse(version)
 
-version_tuple = _exp.version + (
-    ("".join(str(x) for x in _exp.prerelease),)
-    if _exp.prerelease is not None
+version_tuple = _exp._version + (
+    ("".join(str(x) for x in _exp.pre),)
+    if _exp.is_prerelease
     else ("",)
 )
 
-api_version_tuple = (0, 18, 0)
-api_version = "0.18.0"
+api_version_tuple = (0, 24, 0)
+api_version = "0.24.0"
 
-__doc__ = """\
-This is h5pyd **%s**
+__doc__ = f"""\
+This is h5pyd **{version}**
 
-""" % (
-    version
-)
+"""
 
-info = """\
+info = f"""\
 Summary of the h5pyd configuration
 ---------------------------------
 
-h5pyd    %(h5pyd)s
-Python  %(python)s
-sys.platform    %(platform)s
-sys.maxsize     %(maxsize)s
-numpy   %(numpy)s
-""" % {
-    "h5pyd": version,
-    "python": sys.version,
-    "platform": sys.platform,
-    "maxsize": sys.maxsize,
-    "numpy": numpy.__version__,
-}
+h5pyd    {version}
+Python  {sys.version}
+sys.platform    {sys.platform}
+sys.maxsize     {sys.maxsize}
+numpy   {numpy.__version__}
+"""
